@@ -133,7 +133,7 @@ create_grid (void)
 			     G_CALLBACK (gtk_main_quit),
 			     GTK_OBJECT (box));
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
-   GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
+   gtk_widget_set_can_default(close_button, GTK_CAN_DEFAULT);
    gtk_widget_grab_default (close_button);
 
    gtk_widget_show_all (window);
